@@ -1,4 +1,4 @@
-/* $Id: exo-binding.c 22527 2006-07-25 23:03:26Z benny $ */
+/* $Id: exo-binding.c 28333 2008-10-20 20:07:30Z nick $ */
 /*-
  * Copyright (c) 2004-2006 os-cillation e.K.
  * Copyright (c) 2004      Victor Porton (http://ex-code.com/~porton/)
@@ -507,7 +507,7 @@ exo_mutual_binding_new_with_negation (GObject     *object1,
 void
 exo_mutual_binding_unbind (ExoMutualBinding *binding)
 {
-  g_signal_handler_disconnect (binding->direct.dst_object, binding->direct.handler);
+  g_signal_handler_disconnect (binding->reverse.dst_object, binding->direct.handler);
 }
 
 
